summaryrefslogtreecommitdiffstats
path: root/libkmime
diff options
context:
space:
mode:
Diffstat (limited to 'libkmime')
-rw-r--r--libkmime/boolflags.cpp4
-rw-r--r--libkmime/kmime_charfreq.cpp2
-rw-r--r--libkmime/kmime_charfreq.h2
-rw-r--r--libkmime/kmime_codecs.h6
-rw-r--r--libkmime/kmime_content.cpp34
-rw-r--r--libkmime/kmime_content.h4
-rw-r--r--libkmime/kmime_header_parsing.cpp18
-rw-r--r--libkmime/kmime_header_parsing.h2
-rw-r--r--libkmime/kmime_headers.cpp16
-rw-r--r--libkmime/kmime_headers.h2
-rw-r--r--libkmime/kmime_mdn.cpp4
-rw-r--r--libkmime/kmime_parsers.cpp26
-rw-r--r--libkmime/kmime_util.cpp12
-rw-r--r--libkmime/kmime_util.h4
-rw-r--r--libkmime/tests/test_dates.cpp10
-rw-r--r--libkmime/tests/test_kmime_codec.cpp12
16 files changed, 79 insertions, 79 deletions
diff --git a/libkmime/boolflags.cpp b/libkmime/boolflags.cpp
index 2110acbde..a9ba7a9f8 100644
--- a/libkmime/boolflags.cpp
+++ b/libkmime/boolflags.cpp
@@ -20,7 +20,7 @@ void BoolFlags::set(unsigned int i, bool b)
{
if(i>15) return;
- unsigned char p; //bitmask
+ unsigned char p; //bitqmask
int n;
if(i<8) { //first byte
@@ -43,7 +43,7 @@ bool BoolFlags::get(unsigned int i)
{
if(i>15) return false;
- unsigned char p; //bitmask
+ unsigned char p; //bitqmask
int n;
if(i<8) { //first byte
diff --git a/libkmime/kmime_charfreq.cpp b/libkmime/kmime_charfreq.cpp
index fa496b996..a75d76853 100644
--- a/libkmime/kmime_charfreq.cpp
+++ b/libkmime/kmime_charfreq.cpp
@@ -77,7 +77,7 @@ void CharFreq::count( const char * it, size_t len ) {
break;
case 'F': // check for lines starting with From_ if not found already:
if ( !mLeadingFrom )
- if ( prevChar == '\n' && end - it >= 5 && !qstrncmp( "From ", it, 5 ) )
+ if ( prevChar == '\n' && end - it >= 5 && !tqstrncmp( "From ", it, 5 ) )
mLeadingFrom = true;
++printable;
break;
diff --git a/libkmime/kmime_charfreq.h b/libkmime/kmime_charfreq.h
index e85e063bc..8f2c8bda7 100644
--- a/libkmime/kmime_charfreq.h
+++ b/libkmime/kmime_charfreq.h
@@ -37,7 +37,7 @@ public:
/** Returns true if buf has trailing whitespace, i.e. if any line ends
with space (' ') or tab ('\t'). */
bool hasTrailingWhitespace() const;
- /** Returns true if buf contains a line that starts with "From ". */
+ /** Returns true if buf tqcontains a line that starts with "From ". */
bool hasLeadingFrom() const;
/** Returns the percentage of printable characters: printable/total.
If total == 0, the result is undefined. */
diff --git a/libkmime/kmime_codecs.h b/libkmime/kmime_codecs.h
index 3ff0c4a42..211867bca 100644
--- a/libkmime/kmime_codecs.h
+++ b/libkmime/kmime_codecs.h
@@ -87,7 +87,7 @@ public:
* This function doesn't support chaining of blocks. The returned
* block cannot be added to, but you don't need to finalize it, too.
*
- * Example usage (@p in contains the input data):
+ * Example usage (@p in tqcontains the input data):
* <pre>
* KMime::Codec * codec = KMime::Codec::codecForName( "base64" );
* kdFatal( !codec ) << "no base64 codec found!?" << endl;
@@ -123,7 +123,7 @@ public:
* This function doesn't support chaining of blocks. The returned
* block cannot be added to, but you don't need to finalize it, too.
*
- * Example usage (@p in contains the input data):
+ * Example usage (@p in tqcontains the input data):
* <pre>
* KMime::Codec * codec = KMime::Codec::codecForName( "base64" );
* kdFatal( !codec ) << "no base64 codec found!?" << endl;
@@ -230,7 +230,7 @@ public:
* the output and then delete the decoder instance. If you want to
* process another input block sequence, you create a new instance.
*
- * Typical usage (@p in contains the (base64-encoded) input data),
+ * Typical usage (@p in tqcontains the (base64-encoded) input data),
* taking into account all the conventions detailed above:
*
* <pre>
diff --git a/libkmime/kmime_content.h b/libkmime/kmime_content.h
index 1d2aac2d3..8c828500f 100644
--- a/libkmime/kmime_content.h
+++ b/libkmime/kmime_content.h
@@ -35,7 +35,7 @@ namespace KMime {
/** Base class for messages in mime format
- It contains all the enums, static functions
+ It tqcontains all the enums, static functions
and parser-classes, that are needed for
mime handling */
@@ -110,7 +110,7 @@ class KDE_EXPORT Content : public Base {
void changeEncoding(Headers::contentEncoding e);
//saves the encoded content to the given textstream
- // scrambleFromLines: replace "\nFrom " with "\n>From ", this is
+ // scrambleFromLines: tqreplace "\nFrom " with "\n>From ", this is
// needed to avoid problem with mbox-files
void toStream(TQTextStream &ts, bool scrambleFromLines=false);
diff --git a/libkmime/kmime_header_parsing.cpp b/libkmime/kmime_header_parsing.cpp
index 9222ff914..6b06c9038 100644
--- a/libkmime/kmime_header_parsing.cpp
+++ b/libkmime/kmime_header_parsing.cpp
@@ -256,7 +256,7 @@ bool parseAtom( const char * & scursor, const char * const send,
QPair<const char*,int> maybeResult;
if ( parseAtom( scursor, send, maybeResult, allow8Bit ) ) {
- result += TQString::fromLatin1( maybeResult.first, maybeResult.second );
+ result += TQString::tqfromLatin1( maybeResult.first, maybeResult.second );
return true;
}
@@ -296,7 +296,7 @@ bool parseToken( const char * & scursor, const char * const send,
QPair<const char*,int> maybeResult;
if ( parseToken( scursor, send, maybeResult, allow8Bit ) ) {
- result += TQString::fromLatin1( maybeResult.first, maybeResult.second );
+ result += TQString::tqfromLatin1( maybeResult.first, maybeResult.second );
return true;
}
@@ -1065,9 +1065,9 @@ bool parseAddressList( const char* & scursor, const char * const send,
}
-static TQString asterisk = TQString::fromLatin1("*0*",1);
-static TQString asteriskZero = TQString::fromLatin1("*0*",2);
-//static TQString asteriskZeroAsterisk = TQString::fromLatin1("*0*",3);
+static TQString asterisk = TQString::tqfromLatin1("*0*",1);
+static TQString asteriskZero = TQString::tqfromLatin1("*0*",2);
+//static TQString asteriskZeroAsterisk = TQString::tqfromLatin1("*0*",3);
bool parseParameter( const char* & scursor, const char * const send,
QPair<TQString,QStringOrQPair> & result, bool isCRLF ) {
@@ -1223,7 +1223,7 @@ static void decodeRFC2231Value( Codec* & rfc2231Codec,
// take the whole value to be in latin-1:
KMIME_WARN << "No charset in extended-initial-value. "
"Assuming \"iso-8859-1\"." << endl;
- value += TQString::fromLatin1( decBegin, source.second );
+ value += TQString::tqfromLatin1( decBegin, source.second );
return;
}
@@ -1263,7 +1263,7 @@ static void decodeRFC2231Value( Codec* & rfc2231Codec,
}
if ( !textcodec ) {
- value += TQString::fromLatin1( decCursor, decEnd - decCursor );
+ value += TQString::tqfromLatin1( decCursor, decEnd - decCursor );
return;
}
@@ -1348,7 +1348,7 @@ bool parseParameterList( const char* & scursor, const char * const send,
} else {
// not encoded.
if ( (*it).qpair.first )
- value += TQString::fromLatin1( (*it).qpair.first, (*it).qpair.second );
+ value += TQString::tqfromLatin1( (*it).qpair.first, (*it).qpair.second );
else
value += (*it).qstring;
}
@@ -1377,7 +1377,7 @@ bool parseParameterList( const char* & scursor, const char * const send,
} else {
// not encoded
if ( (*it).qpair.first )
- value += TQString::fromLatin1( (*it).qpair.first, (*it).qpair.second );
+ value += TQString::tqfromLatin1( (*it).qpair.first, (*it).qpair.second );
else
value += (*it).qstring;
}
diff --git a/libkmime/kmime_header_parsing.h b/libkmime/kmime_header_parsing.h
index 699b56e10..10751f034 100644
--- a/libkmime/kmime_header_parsing.h
+++ b/libkmime/kmime_header_parsing.h
@@ -94,7 +94,7 @@ namespace HeaderParsing {
to and including the encoding specifier. The
encoded-text is quite generously parsed and @p ok
is still set to @p true when e.g. the encoded-word
- appears to be truncated or contains whitespace.
+ appears to be truncated or tqcontains whitespace.
@return the decoded string the encoded word represented.
*/
bool parseEncodedWord( const char* & scursor, const char * const send,
diff --git a/libkmime/kmime_headers.cpp b/libkmime/kmime_headers.cpp
index d4557c122..cef3f7a4c 100644
--- a/libkmime/kmime_headers.cpp
+++ b/libkmime/kmime_headers.cpp
@@ -529,7 +529,7 @@ void MessageID::fromUnicodeString(const TQString &s, const TQCString&)
TQString MessageID::asUnicodeString()
{
- return TQString::fromLatin1(m_id);
+ return TQString::tqfromLatin1(m_id);
}
@@ -567,7 +567,7 @@ void Control::fromUnicodeString(const TQString &s, const TQCString&)
TQString Control::asUnicodeString()
{
- return TQString::fromLatin1(c_trlMsg);
+ return TQString::tqfromLatin1(c_trlMsg);
}
//-----</Control>------------------------------
@@ -797,7 +797,7 @@ void Date::fromUnicodeString(const TQString &s, const TQCString&)
TQString Date::asUnicodeString()
{
- return TQString::fromLatin1(as7BitString(false));
+ return TQString::tqfromLatin1(as7BitString(false));
}
@@ -811,7 +811,7 @@ TQDateTime Date::qdt()
int Date::ageInDays()
{
- TQDate today=TQDate::currentDate();
+ TQDate today=TQDate::tqcurrentDate();
return ( qdt().date().daysTo(today) );
}
@@ -1075,7 +1075,7 @@ void References::fromUnicodeString(const TQString &s, const TQCString&)
TQString References::asUnicodeString()
{
- return TQString::fromLatin1(r_ef);
+ return TQString::tqfromLatin1(r_ef);
}
@@ -1221,7 +1221,7 @@ void UserAgent::fromUnicodeString(const TQString &s, const TQCString&)
TQString UserAgent::asUnicodeString()
{
- return TQString::fromLatin1(u_agent);
+ return TQString::tqfromLatin1(u_agent);
}
//-----</UserAgent>----------------------------
@@ -1268,7 +1268,7 @@ void ContentType::fromUnicodeString(const TQString &s, const TQCString&)
TQString ContentType::asUnicodeString()
{
- return TQString::fromLatin1(as7BitString(false));
+ return TQString::tqfromLatin1(as7BitString(false));
}
@@ -1544,7 +1544,7 @@ void CTEncoding::fromUnicodeString(const TQString &s, const TQCString&)
TQString CTEncoding::asUnicodeString()
{
- return TQString::fromLatin1(as7BitString(false));
+ return TQString::tqfromLatin1(as7BitString(false));
}
//-----</CTEncoding>---------------------------
diff --git a/libkmime/kmime_headers.h b/libkmime/kmime_headers.h
index 2ba0e1b8d..1c980a040 100644
--- a/libkmime/kmime_headers.h
+++ b/libkmime/kmime_headers.h
@@ -239,7 +239,7 @@ private:
};
/** This is the base class for all structured header fields. It
- contains parsing methods for all basic token types found in
+ tqcontains parsing methods for all basic token types found in
rfc2822.
@section Parsing
diff --git a/libkmime/kmime_mdn.cpp b/libkmime/kmime_mdn.cpp
index 75f1a91e9..702f5f811 100644
--- a/libkmime/kmime_mdn.cpp
+++ b/libkmime/kmime_mdn.cpp
@@ -240,9 +240,9 @@ namespace MDN {
// headers that are only present for certain disposition {types,modifiers}:
if ( d == Failed )
result += "Failure: " + encodeRFC2047String( spec, "utf-8" ) + "\n";
- else if ( m.contains( Error ) )
+ else if ( m.tqcontains( Error ) )
result += "Error: " + encodeRFC2047String( spec, "utf-8" ) + "\n";
- else if ( m.contains( Warning ) )
+ else if ( m.tqcontains( Warning ) )
result += "Warning: " + encodeRFC2047String( spec, "utf-8" ) + "\n";
return result;
diff --git a/libkmime/kmime_parsers.cpp b/libkmime/kmime_parsers.cpp
index 6527c9912..446f1af7c 100644
--- a/libkmime/kmime_parsers.cpp
+++ b/libkmime/kmime_parsers.cpp
@@ -149,11 +149,11 @@ bool UUEncoded::parse()
while (success) {
int beginPos=currentPos, uuStart=currentPos, endPos=0, lineCount=0, MCount=0, pos=0, len=0;
- bool containsBegin=false, containsEnd=false;
+ bool tqcontainsBegin=false, tqcontainsEnd=false;
TQCString tmp,fileName;
if( (beginPos=s_rc.find(TQRegExp("begin [0-9][0-9][0-9]"),currentPos))>-1 && (beginPos==0 || s_rc.at(beginPos-1)=='\n') ) {
- containsBegin=true;
+ tqcontainsBegin=true;
uuStart=s_rc.find('\n', beginPos);
if(uuStart==-1) {//no more line breaks found, we give up
success = false;
@@ -166,9 +166,9 @@ bool UUEncoded::parse()
if ( (endPos=s_rc.find("\nend",(uuStart>0)? uuStart-1:0))==-1 )
endPos=s_rc.length(); //no end found
else
- containsEnd=true;
+ tqcontainsEnd=true;
- if ((containsBegin && containsEnd) || firstIteration) {
+ if ((tqcontainsBegin && tqcontainsEnd) || firstIteration) {
//printf("beginPos=%d , uuStart=%d , endPos=%d\n", beginPos, uuStart, endPos);
//all lines in a uuencoded text start with 'M'
@@ -183,12 +183,12 @@ bool UUEncoded::parse()
//printf("lineCount=%d , MCount=%d\n", lineCount, MCount);
if( MCount==0 || (lineCount-MCount)>10 ||
- ((!containsBegin || !containsEnd) && (MCount<15)) ) { // harder check for splitted-articles
+ ((!tqcontainsBegin || !tqcontainsEnd) && (MCount<15)) ) { // harder check for splitted-articles
success = false;
break; //too many "non-M-Lines" found, we give up
}
- if( (!containsBegin || !containsEnd) && s_ubject) { // message may be split up => parse subject
+ if( (!tqcontainsBegin || !tqcontainsEnd) && s_ubject) { // message may be split up => parse subject
TQRegExp rx("[0-9]+/[0-9]+");
pos=rx.search(TQString(s_ubject), 0);
len=rx.matchedLength();
@@ -207,7 +207,7 @@ bool UUEncoded::parse()
if(beginPos>0)
t_ext.append(s_rc.mid(currentPos,beginPos-currentPos));
- if(containsBegin)
+ if(tqcontainsBegin)
fileName = s_rc.mid(beginPos+10, uuStart-beginPos-11); //everything between "begin ### " and the next LF is considered as the filename
else
fileName = "";
@@ -281,7 +281,7 @@ bool YENCEncoded::parse()
while (success) {
int beginPos=currentPos, yencStart=currentPos;
- bool containsPart=false;
+ bool tqcontainsPart=false;
TQCString fileName,mimeType;
if ((beginPos=s_rc.find("=ybegin ", currentPos))>-1 && ( beginPos==0 || s_rc.at( beginPos-1)=='\n') ) {
@@ -292,7 +292,7 @@ bool YENCEncoded::parse()
} else {
yencStart++;
if (s_rc.find("=ypart", yencStart)==yencStart) {
- containsPart=true;
+ tqcontainsPart=true;
yencStart=s_rc.find( '\n', yencStart);
if ( yencStart== -1) {
success=false;
@@ -332,7 +332,7 @@ bool YENCEncoded::parse()
}
int partBegin, partEnd;
- if (containsPart) {
+ if (tqcontainsPart) {
if (!yencMeta(meta, "part", &p_artNr)) {
success=false;
break;
@@ -355,7 +355,7 @@ bool YENCEncoded::parse()
int len=s_rc.length();
bool lineStart=true;
int lineLength=0;
- bool containsEnd=false;
+ bool tqcontainsEnd=false;
TQByteArray binary = TQByteArray(yencSize);
while (pos<len) {
int ch=s_rc.at(pos);
@@ -382,7 +382,7 @@ bool YENCEncoded::parse()
ch=s_rc.at( pos+1);
if (lineStart && ch=='y')
{
- containsEnd=true;
+ tqcontainsEnd=true;
break;
}
pos+=2;
@@ -412,7 +412,7 @@ bool YENCEncoded::parse()
}
}
- if (!containsEnd)
+ if (!tqcontainsEnd)
{
success=false;
break;
diff --git a/libkmime/kmime_util.cpp b/libkmime/kmime_util.cpp
index 313aabe72..2f0d04a1f 100644
--- a/libkmime/kmime_util.cpp
+++ b/libkmime/kmime_util.cpp
@@ -400,7 +400,7 @@ TQCString extractHeader(const TQCString &src, const char *name)
if (!folded)
return src.mid(pos1, pos2-pos1);
else
- return (src.mid(pos1, pos2-pos1).replace(TQRegExp("\\s*\\n\\s*")," "));
+ return (src.mid(pos1, pos2-pos1).tqreplace(TQRegExp("\\s*\\n\\s*")," "));
}
else {
return TQCString(0); //header not found
@@ -411,7 +411,7 @@ TQCString extractHeader(const TQCString &src, const char *name)
TQCString CRLFtoLF(const TQCString &s)
{
TQCString ret=s.copy();
- ret.replace(TQRegExp("\\r\\n"), "\n");
+ ret.tqreplace(TQRegExp("\\r\\n"), "\n");
return ret;
}
@@ -419,7 +419,7 @@ TQCString CRLFtoLF(const TQCString &s)
TQCString CRLFtoLF(const char *s)
{
TQCString ret=s;
- ret.replace(TQRegExp("\\r\\n"), "\n");
+ ret.tqreplace(TQRegExp("\\r\\n"), "\n");
return ret;
}
@@ -427,7 +427,7 @@ TQCString CRLFtoLF(const char *s)
TQCString LFtoCRLF(const TQCString &s)
{
TQCString ret=s.copy();
- ret.replace(TQRegExp("\\n"), "\r\n");
+ ret.tqreplace(TQRegExp("\\n"), "\r\n");
return ret;
}
@@ -563,7 +563,7 @@ DateFormatter::custom(time_t t) const
d.setTime_t(t);
if ( z != -1 ) {
- ret.replace(z,1,zone(t));
+ ret.tqreplace(z,1,zone(t));
}
ret = d.toString(ret);
@@ -737,7 +737,7 @@ DateFormatter::localized(time_t otime, bool shortFormat, bool includeSecs,
QString
DateFormatter::cTime(time_t otime) const
{
- return TQString::fromLatin1( ctime( &otime ) ).stripWhiteSpace() ;
+ return TQString::tqfromLatin1( ctime( &otime ) ).stripWhiteSpace() ;
}
QString
diff --git a/libkmime/tests/test_dates.cpp b/libkmime/tests/test_dates.cpp
index 7087a01a6..e3a40f812 100644
--- a/libkmime/tests/test_dates.cpp
+++ b/libkmime/tests/test_dates.cpp
@@ -80,14 +80,14 @@ main()
"Z MMMM dddd yyyy") <<endl;
t.setFormat(DateFormatter::Fancy);
kdDebug()<<"TQDateTime taking: (dates as in first test)"<<endl;
- kdDebug()<<"\tFancy : \t"<<t.dateString((TQDateTime::currentDateTime()))<<endl;
+ kdDebug()<<"\tFancy : \t"<<t.dateString((TQDateTime::tqcurrentDateTime()))<<endl;
t.setFormat(DateFormatter::Localized);
- kdDebug()<<"\tLocalized : \t"<<t.dateString(TQDateTime::currentDateTime())<<endl;
+ kdDebug()<<"\tLocalized : \t"<<t.dateString(TQDateTime::tqcurrentDateTime())<<endl;
t.setFormat(DateFormatter::CTime);
- kdDebug()<<"\tCTime : \t"<<t.dateString(TQDateTime::currentDateTime())<<endl;
+ kdDebug()<<"\tCTime : \t"<<t.dateString(TQDateTime::tqcurrentDateTime())<<endl;
t.setFormat(DateFormatter::Iso);
- kdDebug()<<"\tIso : \t"<<t.dateString(TQDateTime::currentDateTime())<<endl;
+ kdDebug()<<"\tIso : \t"<<t.dateString(TQDateTime::tqcurrentDateTime())<<endl;
t.setCustomFormat("MMMM d dddd yyyy Z");
- kdDebug()<<"\tCustom : \t"<<t.dateString(TQDateTime::currentDateTime())<<endl;
+ kdDebug()<<"\tCustom : \t"<<t.dateString(TQDateTime::tqcurrentDateTime())<<endl;
}
diff --git a/libkmime/tests/test_kmime_codec.cpp b/libkmime/tests/test_kmime_codec.cpp
index e30a89ac9..68ab08ec7 100644
--- a/libkmime/tests/test_kmime_codec.cpp
+++ b/libkmime/tests/test_kmime_codec.cpp
@@ -239,8 +239,8 @@ void encode_decode_convenience_qba( bool encode, const Codec * codec,
else
out = codec->decode( infile_buffer, withCRLF );
if ( writing ) {
- Q_LONG written = outfile.writeBlock( out );
- assert( written == (Q_LONG)out.size() );
+ TQ_LONG written = outfile.writeBlock( out );
+ assert( written == (TQ_LONG)out.size() );
}
}
@@ -304,8 +304,8 @@ void encode_decode_kio( bool encode, const Codec * codec,
else
decode_kio_internal( dec, iit, iend, out );
if ( writing && out.size() ) {
- Q_LONG written = outfile.writeBlock( out );
- assert( written == (Q_LONG)out.size() );
+ TQ_LONG written = outfile.writeBlock( out );
+ assert( written == (TQ_LONG)out.size() );
}
} while ( out.size() );
@@ -329,7 +329,7 @@ void encode_decode_chunkwise( bool encode, const Codec * codec,
#define write_full_outdata_then_reset do { \
kdDebug( verbose ) << " flushing output buffer." << endl; \
if ( writing ) { \
- Q_LONG outlen = outfile.writeBlock( outdata.data(), \
+ TQ_LONG outlen = outfile.writeBlock( outdata.data(), \
outdata.size() ); \
if ( outlen != (int)outdata.size() ) \
exit(OUTFILE_WRITE_ERR); \
@@ -432,7 +432,7 @@ void encode_decode_chunkwise( bool encode, const Codec * codec,
// Write out last (partial) output chunk:
//
if ( writing ) {
- Q_LONG outlen = outfile.writeBlock( outdata.data(),
+ TQ_LONG outlen = outfile.writeBlock( outdata.data(),
oit - outdata.begin() );
if ( outlen != oit - outdata.begin() )
exit(OUTFILE_WRITE_ERR);
diff --git a/libkmime/kmime_content.cpp b/libkmime/kmime_content.cpp
index 6eca383fa..b6b6229f0 100644
--- a/libkmime/kmime_content.cpp
+++ b/libkmime/kmime_content.cpp
@@ -313,9 +313,9 @@ TQCString Content::encodedContent(bool useCrLf)
// add proper mime headers...
if (convertNonMimeBinaries) {
- h_ead.replace(TQRegExp("MIME-Version: .*\\n"),"");
- h_ead.replace(TQRegExp("Content-Type: .*\\n"),"");
- h_ead.replace(TQRegExp("Content-Transfer-Encoding: .*\\n"),"");
+ h_ead.tqreplace(TQRegExp("MIME-Version: .*\\n"),"");
+ h_ead.tqreplace(TQRegExp("Content-Type: .*\\n"),"");
+ h_ead.tqreplace(TQRegExp("Content-Transfer-Encoding: .*\\n"),"");
h_ead+="MIME-Version: 1.0\n";
h_ead+=contentType(true)->as7BitString()+"\n";
h_ead+=contentTransferEncoding(true)->as7BitString()+"\n";
@@ -327,7 +327,7 @@ TQCString Content::encodedContent(bool useCrLf)
e+="\n";
//body
- if(!b_ody.isEmpty()) { //this message contains only one part
+ if(!b_ody.isEmpty()) { //this message tqcontains only one part
Headers::CTEncoding *enc=contentTransferEncoding();
if(enc->needToEncode()) {
@@ -439,25 +439,25 @@ void Content::decodedText(TQStringList &l, bool trimText,
if(!decodeText()) //this is not a text content !!
return;
- TQString unicode;
+ TQString tqunicode;
bool ok=true;
TQTextCodec *codec=KGlobal::charsets()->codecForName(contentType()->charset(),ok);
- unicode=codec->toUnicode(b_ody.data(), b_ody.length());
+ tqunicode=codec->toUnicode(b_ody.data(), b_ody.length());
if (trimText && removeTrailingNewlines) {
int i;
- for (i=unicode.length()-1; i>=0; i--)
- if (!unicode[i].isSpace())
+ for (i=tqunicode.length()-1; i>=0; i--)
+ if (!tqunicode[i].isSpace())
break;
- unicode.truncate(i+1);
+ tqunicode.truncate(i+1);
} else {
- if (unicode.right(1)=="\n")
- unicode.truncate(unicode.length()-1); // remove trailing new-line
+ if (tqunicode.right(1)=="\n")
+ tqunicode.truncate(tqunicode.length()-1); // remove trailing new-line
}
- l=TQStringList::split('\n', unicode, true); //split the string at linebreaks
+ l=TQStringList::split('\n', tqunicode, true); //split the string at linebreaks
}
@@ -630,7 +630,7 @@ void Content::changeEncoding(Headers::contentEncoding e)
if(decodeText())
enc->setCte(e); // text is not encoded until it's sent or saved so we just set the new encoding
- else { // this content contains non textual data, that has to be re-encoded
+ else { // this content tqcontains non textual data, that has to be re-encoded
if(e!=Headers::CEbase64) {
//kdWarning(5003) << "Content::changeEncoding() : non textual data and encoding != base64 - this should not happen\n => forcing base64" << endl;
@@ -652,7 +652,7 @@ void Content::toStream(TQTextStream &ts, bool scrambleFromLines)
TQCString ret=encodedContent(false);
if (scrambleFromLines)
- ret.replace(TQRegExp("\\n\\nFrom "), "\n\n>From ");
+ ret.tqreplace(TQRegExp("\\n\\nFrom "), "\n\n>From ");
ts << ret;
}
@@ -684,7 +684,7 @@ Headers::Generic* Content::getNextHeader(TQCString &head)
if (!folded)
header = new Headers::Generic(head.left(pos1-2), this, head.mid(pos1, pos2-pos1));
else
- header = new Headers::Generic(head.left(pos1-2), this, head.mid(pos1, pos2-pos1).replace(TQRegExp("\\s*\\n\\s*")," "));
+ header = new Headers::Generic(head.left(pos1-2), this, head.mid(pos1, pos2-pos1).tqreplace(TQRegExp("\\s*\\n\\s*")," "));
head.remove(0,pos2+1);
}
@@ -816,8 +816,8 @@ int Content::lineCount()
{
int ret=0;
if(type()==ATmimeContent)
- ret+=h_ead.contains('\n');
- ret+=b_ody.contains('\n');
+ ret+=h_ead.tqcontains('\n');
+ ret+=b_ody.tqcontains('\n');
if(c_ontents && !c_ontents->isEmpty())
for(Content *c=c_ontents->first(); c; c=c_ontents->next())
diff --git a/libkmime/kmime_util.h b/libkmime/kmime_util.h
index e2b3c8334..3c710ab72 100644
--- a/libkmime/kmime_util.h
+++ b/libkmime/kmime_util.h
@@ -35,7 +35,7 @@ namespace KMime {
keeping strings in a common repository.*/
extern const char* cachedLanguage(const TQCString &name) KDE_EXPORT;
/** checks whether @p s contains any non-us-ascii characters */
extern bool isUsAscii(const TQString &s) KDE_EXPORT;
inline bool isOfSet(const uchar map[16], unsigned char ch) {
@@ -167,7 +167,7 @@ namespace KMime {
*/
KDE_EXPORT extern void removeQuots(TQString &str);
/** Converts the given string into a quoted-string if
- the string contains any special characters
+ the string tqcontains any special characters
(ie. one of ()<>@,.;:[]=\").
@param str us-ascii string to work on.
@param forceQuotes if @p true, always add quote characters.
@@ -35,7 +35,7 @@ namespace KMime {
keeping strings in a common repository.*/
extern const char* cachedLanguage(const TQCString &name) KDE_EXPORT;
- /** checks whether @p s contains any non-us-ascii characters */
+ /** checks whether @p s tqcontains any non-us-ascii characters */
extern bool isUsAscii(const TQString &s) KDE_EXPORT;
inline bool isOfSet(const uchar map[16], unsigned char ch) {